@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # srecord - Manipulate EPROM load files
-# Copyright (C) 2009 Peter Miller
+# Copyright (C) 2009, 2010 Peter Miller
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,11 +36,34 @@ S9030000FC
 fubar
 if test $? -ne 0; then no_result; fi
 
-srec_cat test.in -sha224 0x100 -o test.out
-if test $? -ne 0; then fail; fi
+cat > ok2 << 'fubar'
+srec_cat: libgcrypt SHA224 not available
+fubar
+if test $? -ne 0; then no_result; fi
+
+srec_cat test.in -sha224 0x100 -o test.out > LOG 2>&1
+if test $? -ne 0
+then
+    # if SHA224 not available, pass by default
+    if diff ok2 LOG > /dev/null 2> /dev/null
+    then
+        echo
+        echo "    Your gcrypt library does not appear to have SHA224 support,"
+        echo "    this test is therefore declaraed to pass by default."
+        echo
+        pass
+    fi
+
+    # some other error
+    cat LOG
+    fail
+fi
 
 diff test.ok test.out
-if test $? -ne 0; then fail; fi
+if test $? -ne 0
+then
+    fail
+fi
 
 #
 # The things tested here, worked.
